
#ifndef TEXTADDONSWIDGETS_EXPORT_H
#define TEXTADDONSWIDGETS_EXPORT_H

#ifdef TEXTADDONSWIDGETS_STATIC_DEFINE
#  define TEXTADDONSWIDGETS_EXPORT
#  define TEXTADDONSWIDGETS_NO_EXPORT
#else
#  ifndef TEXTADDONSWIDGETS_EXPORT
#    ifdef KF6TextAddonsWidgets_EXPORTS
        /* We are building this library */
#      define TEXTADDONSWIDGETS_EXPORT __attribute__((visibility("default")))
#    else
        /* We are using this library */
#      define TEXTADDONSWIDGETS_EXPORT __attribute__((visibility("default")))
#    endif
#  endif

#  ifndef TEXTADDONSWIDGETS_NO_EXPORT
#    define TEXTADDONSWIDGETS_NO_EXPORT __attribute__((visibility("hidden")))
#  endif
#endif

#ifndef TEXTADDONSWIDGETS_DECL_DEPRECATED
#  define TEXTADDONSWIDGETS_DECL_DEPRECATED __attribute__ ((__deprecated__))
#endif

#ifndef TEXTADDONSWIDGETS_DECL_DEPRECATED_EXPORT
#  define TEXTADDONSWIDGETS_DECL_DEPRECATED_EXPORT TEXTADDONSWIDGETS_EXPORT TEXTADDONSWIDGETS_DECL_DEPRECATED
#endif

#ifndef TEXTADDONSWIDGETS_DECL_DEPRECATED_NO_EXPORT
#  define TEXTADDONSWIDGETS_DECL_DEPRECATED_NO_EXPORT TEXTADDONSWIDGETS_NO_EXPORT TEXTADDONSWIDGETS_DECL_DEPRECATED
#endif

/* NOLINTNEXTLINE(readability-avoid-unconditional-preprocessor-if) */
#if 0 /* DEFINE_NO_DEPRECATED */
#  ifndef TEXTADDONSWIDGETS_NO_DEPRECATED
#    define TEXTADDONSWIDGETS_NO_DEPRECATED
#  endif
#endif
#include <textaddonswidgets_version.h>

#define TEXTADDONSWIDGETS_DECL_DEPRECATED_TEXT(text) __attribute__ ((__deprecated__(text)))

#if defined(TEXTADDONSWIDGETS_NO_DEPRECATED)
#  undef TEXTADDONSWIDGETS_DEPRECATED
#  define TEXTADDONSWIDGETS_DEPRECATED_EXPORT TEXTADDONSWIDGETS_EXPORT
#  define TEXTADDONSWIDGETS_DEPRECATED_NO_EXPORT TEXTADDONSWIDGETS_NO_EXPORT
#elif defined(TEXTADDONSWIDGETS_NO_DEPRECATED_WARNINGS)
#  define TEXTADDONSWIDGETS_DEPRECATED
#  define TEXTADDONSWIDGETS_DEPRECATED_EXPORT TEXTADDONSWIDGETS_EXPORT
#  define TEXTADDONSWIDGETS_DEPRECATED_NO_EXPORT TEXTADDONSWIDGETS_NO_EXPORT
#else
#  define TEXTADDONSWIDGETS_DEPRECATED TEXTADDONSWIDGETS_DECL_DEPRECATED
#  define TEXTADDONSWIDGETS_DEPRECATED_EXPORT TEXTADDONSWIDGETS_DECL_DEPRECATED_EXPORT
#  define TEXTADDONSWIDGETS_DEPRECATED_NO_EXPORT TEXTADDONSWIDGETS_DECL_DEPRECATED_NO_EXPORT
#endif

/* No deprecated API had been removed from build */
#define TEXTADDONSWIDGETS_EXCLUDE_DEPRECATED_BEFORE_AND_AT 0

#define TEXTADDONSWIDGETS_BUILD_DEPRECATED_SINCE(major, minor) 1

#ifdef TEXTADDONSWIDGETS_NO_DEPRECATED
#  define TEXTADDONSWIDGETS_DISABLE_DEPRECATED_BEFORE_AND_AT TEXTADDONSWIDGETS_VERSION
#endif
#ifdef TEXTADDONSWIDGETS_NO_DEPRECATED_WARNINGS
#  define TEXTADDONSWIDGETS_DEPRECATED_WARNINGS_SINCE 0
#endif

#ifndef TEXTADDONSWIDGETS_DEPRECATED_WARNINGS_SINCE
#  ifdef TEXTADDONSWIDGETS_DISABLE_DEPRECATED_BEFORE_AND_AT
#    define TEXTADDONSWIDGETS_DEPRECATED_WARNINGS_SINCE TEXTADDONSWIDGETS_DISABLE_DEPRECATED_BEFORE_AND_AT
#  else
#    define TEXTADDONSWIDGETS_DEPRECATED_WARNINGS_SINCE TEXTADDONSWIDGETS_VERSION
#  endif
#endif

#ifndef TEXTADDONSWIDGETS_DISABLE_DEPRECATED_BEFORE_AND_AT
#  define TEXTADDONSWIDGETS_DISABLE_DEPRECATED_BEFORE_AND_AT 0
#endif

#ifdef TEXTADDONSWIDGETS_DEPRECATED
#  define TEXTADDONSWIDGETS_ENABLE_DEPRECATED_SINCE(major, minor) (((major<<16)|(minor<<8)) > TEXTADDONSWIDGETS_DISABLE_DEPRECATED_BEFORE_AND_AT)
#else
#  define TEXTADDONSWIDGETS_ENABLE_DEPRECATED_SINCE(major, minor) 0
#endif

#if TEXTADDONSWIDGETS_DEPRECATED_WARNINGS_SINCE >= 0x10900
#  define TEXTADDONSWIDGETS_DEPRECATED_VERSION_1_9(text) TEXTADDONSWIDGETS_DECL_DEPRECATED_TEXT(text)
#else
#  define TEXTADDONSWIDGETS_DEPRECATED_VERSION_1_9(text)
#endif
#define TEXTADDONSWIDGETS_DEPRECATED_VERSION_1(minor, text)      TEXTADDONSWIDGETS_DEPRECATED_VERSION_1_##minor(text)
#define TEXTADDONSWIDGETS_DEPRECATED_VERSION(major, minor, text) TEXTADDONSWIDGETS_DEPRECATED_VERSION_##major(minor, "Since "#major"."#minor". " text)
#define TEXTADDONSWIDGETS_DEPRECATED_VERSION_BELATED(major, minor, textmajor, textminor, text) TEXTADDONSWIDGETS_DEPRECATED_VERSION_##major(minor, "Since "#textmajor"."#textminor". " text)
#if defined(__cpp_enumerator_attributes) && __cpp_enumerator_attributes >= 201411
#  define TEXTADDONSWIDGETS_ENUMERATOR_DEPRECATED_VERSION(major, minor, text) TEXTADDONSWIDGETS_DEPRECATED_VERSION(major, minor, text)
#  define TEXTADDONSWIDGETS_ENUMERATOR_DEPRECATED_VERSION_BELATED(major, minor, textmajor, textminor, text) TEXTADDONSWIDGETS_DEPRECATED_VERSION_BELATED(major, minor, textmajor, textminor, text)
#else
#  define TEXTADDONSWIDGETS_ENUMERATOR_DEPRECATED_VERSION(major, minor, text)
#  define TEXTADDONSWIDGETS_ENUMERATOR_DEPRECATED_VERSION_BELATED(major, minor, textmajor, textminor, text)
#endif

#endif /* TEXTADDONSWIDGETS_EXPORT_H */
