
#ifndef TEXTAUTOGENERATETEXT_EXPORT_H
#define TEXTAUTOGENERATETEXT_EXPORT_H

#ifdef TEXTAUTOGENERATETEXT_STATIC_DEFINE
#  define TEXTAUTOGENERATETEXT_EXPORT
#  define TEXTAUTOGENERATETEXT_NO_EXPORT
#else
#  ifndef TEXTAUTOGENERATETEXT_EXPORT
#    ifdef KF6TextAutoGenerateText_EXPORTS
        /* We are building this library */
#      define TEXTAUTOGENERATETEXT_EXPORT __attribute__((visibility("default")))
#    else
        /* We are using this library */
#      define TEXTAUTOGENERATETEXT_EXPORT __attribute__((visibility("default")))
#    endif
#  endif

#  ifndef TEXTAUTOGENERATETEXT_NO_EXPORT
#    define TEXTAUTOGENERATETEXT_NO_EXPORT __attribute__((visibility("hidden")))
#  endif
#endif

#ifndef TEXTAUTOGENERATETEXT_DECL_DEPRECATED
#  define TEXTAUTOGENERATETEXT_DECL_DEPRECATED __attribute__ ((__deprecated__))
#endif

#ifndef TEXTAUTOGENERATETEXT_DECL_DEPRECATED_EXPORT
#  define TEXTAUTOGENERATETEXT_DECL_DEPRECATED_EXPORT TEXTAUTOGENERATETEXT_EXPORT TEXTAUTOGENERATETEXT_DECL_DEPRECATED
#endif

#ifndef TEXTAUTOGENERATETEXT_DECL_DEPRECATED_NO_EXPORT
#  define TEXTAUTOGENERATETEXT_DECL_DEPRECATED_NO_EXPORT TEXTAUTOGENERATETEXT_NO_EXPORT TEXTAUTOGENERATETEXT_DECL_DEPRECATED
#endif

/* NOLINTNEXTLINE(readability-avoid-unconditional-preprocessor-if) */
#if 0 /* DEFINE_NO_DEPRECATED */
#  ifndef TEXTAUTOGENERATETEXT_NO_DEPRECATED
#    define TEXTAUTOGENERATETEXT_NO_DEPRECATED
#  endif
#endif
#include <textautogeneratetext_version.h>

#define TEXTAUTOGENERATETEXT_DECL_DEPRECATED_TEXT(text) __attribute__ ((__deprecated__(text)))

#if defined(TEXTAUTOGENERATETEXT_NO_DEPRECATED)
#  undef TEXTAUTOGENERATETEXT_DEPRECATED
#  define TEXTAUTOGENERATETEXT_DEPRECATED_EXPORT TEXTAUTOGENERATETEXT_EXPORT
#  define TEXTAUTOGENERATETEXT_DEPRECATED_NO_EXPORT TEXTAUTOGENERATETEXT_NO_EXPORT
#elif defined(TEXTAUTOGENERATETEXT_NO_DEPRECATED_WARNINGS)
#  define TEXTAUTOGENERATETEXT_DEPRECATED
#  define TEXTAUTOGENERATETEXT_DEPRECATED_EXPORT TEXTAUTOGENERATETEXT_EXPORT
#  define TEXTAUTOGENERATETEXT_DEPRECATED_NO_EXPORT TEXTAUTOGENERATETEXT_NO_EXPORT
#else
#  define TEXTAUTOGENERATETEXT_DEPRECATED TEXTAUTOGENERATETEXT_DECL_DEPRECATED
#  define TEXTAUTOGENERATETEXT_DEPRECATED_EXPORT TEXTAUTOGENERATETEXT_DECL_DEPRECATED_EXPORT
#  define TEXTAUTOGENERATETEXT_DEPRECATED_NO_EXPORT TEXTAUTOGENERATETEXT_DECL_DEPRECATED_NO_EXPORT
#endif

/* No deprecated API had been removed from build */
#define TEXTAUTOGENERATETEXT_EXCLUDE_DEPRECATED_BEFORE_AND_AT 0

#define TEXTAUTOGENERATETEXT_BUILD_DEPRECATED_SINCE(major, minor) 1

#ifdef TEXTAUTOGENERATETEXT_NO_DEPRECATED
#  define TEXTAUTOGENERATETEXT_DISABLE_DEPRECATED_BEFORE_AND_AT TEXTAUTOGENERATETEXT_VERSION
#endif
#ifdef TEXTAUTOGENERATETEXT_NO_DEPRECATED_WARNINGS
#  define TEXTAUTOGENERATETEXT_DEPRECATED_WARNINGS_SINCE 0
#endif

#ifndef TEXTAUTOGENERATETEXT_DEPRECATED_WARNINGS_SINCE
#  ifdef TEXTAUTOGENERATETEXT_DISABLE_DEPRECATED_BEFORE_AND_AT
#    define TEXTAUTOGENERATETEXT_DEPRECATED_WARNINGS_SINCE TEXTAUTOGENERATETEXT_DISABLE_DEPRECATED_BEFORE_AND_AT
#  else
#    define TEXTAUTOGENERATETEXT_DEPRECATED_WARNINGS_SINCE TEXTAUTOGENERATETEXT_VERSION
#  endif
#endif

#ifndef TEXTAUTOGENERATETEXT_DISABLE_DEPRECATED_BEFORE_AND_AT
#  define TEXTAUTOGENERATETEXT_DISABLE_DEPRECATED_BEFORE_AND_AT 0x20000
#endif

#ifdef TEXTAUTOGENERATETEXT_DEPRECATED
#  define TEXTAUTOGENERATETEXT_ENABLE_DEPRECATED_SINCE(major, minor) (((major<<16)|(minor<<8)) > TEXTAUTOGENERATETEXT_DISABLE_DEPRECATED_BEFORE_AND_AT)
#else
#  define TEXTAUTOGENERATETEXT_ENABLE_DEPRECATED_SINCE(major, minor) 0
#endif

#endif /* TEXTAUTOGENERATETEXT_EXPORT_H */
