
#ifndef TEXTTRANSLATOR_EXPORT_H
#define TEXTTRANSLATOR_EXPORT_H

#ifdef TEXTTRANSLATOR_STATIC_DEFINE
#  define TEXTTRANSLATOR_EXPORT
#  define TEXTTRANSLATOR_NO_EXPORT
#else
#  ifndef TEXTTRANSLATOR_EXPORT
#    ifdef KF6TextTranslator_EXPORTS
        /* We are building this library */
#      define TEXTTRANSLATOR_EXPORT __attribute__((visibility("default")))
#    else
        /* We are using this library */
#      define TEXTTRANSLATOR_EXPORT __attribute__((visibility("default")))
#    endif
#  endif

#  ifndef TEXTTRANSLATOR_NO_EXPORT
#    define TEXTTRANSLATOR_NO_EXPORT __attribute__((visibility("hidden")))
#  endif
#endif

#ifndef TEXTTRANSLATOR_DECL_DEPRECATED
#  define TEXTTRANSLATOR_DECL_DEPRECATED __attribute__ ((__deprecated__))
#endif

#ifndef TEXTTRANSLATOR_DECL_DEPRECATED_EXPORT
#  define TEXTTRANSLATOR_DECL_DEPRECATED_EXPORT TEXTTRANSLATOR_EXPORT TEXTTRANSLATOR_DECL_DEPRECATED
#endif

#ifndef TEXTTRANSLATOR_DECL_DEPRECATED_NO_EXPORT
#  define TEXTTRANSLATOR_DECL_DEPRECATED_NO_EXPORT TEXTTRANSLATOR_NO_EXPORT TEXTTRANSLATOR_DECL_DEPRECATED
#endif

/* NOLINTNEXTLINE(readability-avoid-unconditional-preprocessor-if) */
#if 0 /* DEFINE_NO_DEPRECATED */
#  ifndef TEXTTRANSLATOR_NO_DEPRECATED
#    define TEXTTRANSLATOR_NO_DEPRECATED
#  endif
#endif
#include <texttranslator_version.h>

#define TEXTTRANSLATOR_DECL_DEPRECATED_TEXT(text) __attribute__ ((__deprecated__(text)))

#if defined(TEXTTRANSLATOR_NO_DEPRECATED)
#  undef TEXTTRANSLATOR_DEPRECATED
#  define TEXTTRANSLATOR_DEPRECATED_EXPORT TEXTTRANSLATOR_EXPORT
#  define TEXTTRANSLATOR_DEPRECATED_NO_EXPORT TEXTTRANSLATOR_NO_EXPORT
#elif defined(TEXTTRANSLATOR_NO_DEPRECATED_WARNINGS)
#  define TEXTTRANSLATOR_DEPRECATED
#  define TEXTTRANSLATOR_DEPRECATED_EXPORT TEXTTRANSLATOR_EXPORT
#  define TEXTTRANSLATOR_DEPRECATED_NO_EXPORT TEXTTRANSLATOR_NO_EXPORT
#else
#  define TEXTTRANSLATOR_DEPRECATED TEXTTRANSLATOR_DECL_DEPRECATED
#  define TEXTTRANSLATOR_DEPRECATED_EXPORT TEXTTRANSLATOR_DECL_DEPRECATED_EXPORT
#  define TEXTTRANSLATOR_DEPRECATED_NO_EXPORT TEXTTRANSLATOR_DECL_DEPRECATED_NO_EXPORT
#endif

/* No deprecated API had been removed from build */
#define TEXTTRANSLATOR_EXCLUDE_DEPRECATED_BEFORE_AND_AT 0

#define TEXTTRANSLATOR_BUILD_DEPRECATED_SINCE(major, minor) 1

#ifdef TEXTTRANSLATOR_NO_DEPRECATED
#  define TEXTTRANSLATOR_DISABLE_DEPRECATED_BEFORE_AND_AT TEXTTRANSLATOR_VERSION
#endif
#ifdef TEXTTRANSLATOR_NO_DEPRECATED_WARNINGS
#  define TEXTTRANSLATOR_DEPRECATED_WARNINGS_SINCE 0
#endif

#ifndef TEXTTRANSLATOR_DEPRECATED_WARNINGS_SINCE
#  ifdef TEXTTRANSLATOR_DISABLE_DEPRECATED_BEFORE_AND_AT
#    define TEXTTRANSLATOR_DEPRECATED_WARNINGS_SINCE TEXTTRANSLATOR_DISABLE_DEPRECATED_BEFORE_AND_AT
#  else
#    define TEXTTRANSLATOR_DEPRECATED_WARNINGS_SINCE TEXTTRANSLATOR_VERSION
#  endif
#endif

#ifndef TEXTTRANSLATOR_DISABLE_DEPRECATED_BEFORE_AND_AT
#  define TEXTTRANSLATOR_DISABLE_DEPRECATED_BEFORE_AND_AT 0x20000
#endif

#ifdef TEXTTRANSLATOR_DEPRECATED
#  define TEXTTRANSLATOR_ENABLE_DEPRECATED_SINCE(major, minor) (((major<<16)|(minor<<8)) > TEXTTRANSLATOR_DISABLE_DEPRECATED_BEFORE_AND_AT)
#else
#  define TEXTTRANSLATOR_ENABLE_DEPRECATED_SINCE(major, minor) 0
#endif

#endif /* TEXTTRANSLATOR_EXPORT_H */
