
#ifndef TEXTEMOTICONSWIDGETS_EXPORT_H
#define TEXTEMOTICONSWIDGETS_EXPORT_H

#ifdef TEXTEMOTICONSWIDGETS_STATIC_DEFINE
#  define TEXTEMOTICONSWIDGETS_EXPORT
#  define TEXTEMOTICONSWIDGETS_NO_EXPORT
#else
#  ifndef TEXTEMOTICONSWIDGETS_EXPORT
#    ifdef KF6TextEmoticonsWidgets_EXPORTS
        /* We are building this library */
#      define TEXTEMOTICONSWIDGETS_EXPORT __attribute__((visibility("default")))
#    else
        /* We are using this library */
#      define TEXTEMOTICONSWIDGETS_EXPORT __attribute__((visibility("default")))
#    endif
#  endif

#  ifndef TEXTEMOTICONSWIDGETS_NO_EXPORT
#    define TEXTEMOTICONSWIDGETS_NO_EXPORT __attribute__((visibility("hidden")))
#  endif
#endif

#ifndef TEXTEMOTICONSWIDGETS_DECL_DEPRECATED
#  define TEXTEMOTICONSWIDGETS_DECL_DEPRECATED __attribute__ ((__deprecated__))
#endif

#ifndef TEXTEMOTICONSWIDGETS_DECL_DEPRECATED_EXPORT
#  define TEXTEMOTICONSWIDGETS_DECL_DEPRECATED_EXPORT TEXTEMOTICONSWIDGETS_EXPORT TEXTEMOTICONSWIDGETS_DECL_DEPRECATED
#endif

#ifndef TEXTEMOTICONSWIDGETS_DECL_DEPRECATED_NO_EXPORT
#  define TEXTEMOTICONSWIDGETS_DECL_DEPRECATED_NO_EXPORT TEXTEMOTICONSWIDGETS_NO_EXPORT TEXTEMOTICONSWIDGETS_DECL_DEPRECATED
#endif

/* NOLINTNEXTLINE(readability-avoid-unconditional-preprocessor-if) */
#if 0 /* DEFINE_NO_DEPRECATED */
#  ifndef TEXTEMOTICONSWIDGETS_NO_DEPRECATED
#    define TEXTEMOTICONSWIDGETS_NO_DEPRECATED
#  endif
#endif
#include <textemoticonswidgets_version.h>

#define TEXTEMOTICONSWIDGETS_DECL_DEPRECATED_TEXT(text) __attribute__ ((__deprecated__(text)))

#if defined(TEXTEMOTICONSWIDGETS_NO_DEPRECATED)
#  undef TEXTEMOTICONSWIDGETS_DEPRECATED
#  define TEXTEMOTICONSWIDGETS_DEPRECATED_EXPORT TEXTEMOTICONSWIDGETS_EXPORT
#  define TEXTEMOTICONSWIDGETS_DEPRECATED_NO_EXPORT TEXTEMOTICONSWIDGETS_NO_EXPORT
#elif defined(TEXTEMOTICONSWIDGETS_NO_DEPRECATED_WARNINGS)
#  define TEXTEMOTICONSWIDGETS_DEPRECATED
#  define TEXTEMOTICONSWIDGETS_DEPRECATED_EXPORT TEXTEMOTICONSWIDGETS_EXPORT
#  define TEXTEMOTICONSWIDGETS_DEPRECATED_NO_EXPORT TEXTEMOTICONSWIDGETS_NO_EXPORT
#else
#  define TEXTEMOTICONSWIDGETS_DEPRECATED TEXTEMOTICONSWIDGETS_DECL_DEPRECATED
#  define TEXTEMOTICONSWIDGETS_DEPRECATED_EXPORT TEXTEMOTICONSWIDGETS_DECL_DEPRECATED_EXPORT
#  define TEXTEMOTICONSWIDGETS_DEPRECATED_NO_EXPORT TEXTEMOTICONSWIDGETS_DECL_DEPRECATED_NO_EXPORT
#endif

/* No deprecated API had been removed from build */
#define TEXTEMOTICONSWIDGETS_EXCLUDE_DEPRECATED_BEFORE_AND_AT 0

#define TEXTEMOTICONSWIDGETS_BUILD_DEPRECATED_SINCE(major, minor) 1

#ifdef TEXTEMOTICONSWIDGETS_NO_DEPRECATED
#  define TEXTEMOTICONSWIDGETS_DISABLE_DEPRECATED_BEFORE_AND_AT TEXTEMOTICONSWIDGETS_VERSION
#endif
#ifdef TEXTEMOTICONSWIDGETS_NO_DEPRECATED_WARNINGS
#  define TEXTEMOTICONSWIDGETS_DEPRECATED_WARNINGS_SINCE 0
#endif

#ifndef TEXTEMOTICONSWIDGETS_DEPRECATED_WARNINGS_SINCE
#  ifdef TEXTEMOTICONSWIDGETS_DISABLE_DEPRECATED_BEFORE_AND_AT
#    define TEXTEMOTICONSWIDGETS_DEPRECATED_WARNINGS_SINCE TEXTEMOTICONSWIDGETS_DISABLE_DEPRECATED_BEFORE_AND_AT
#  else
#    define TEXTEMOTICONSWIDGETS_DEPRECATED_WARNINGS_SINCE TEXTEMOTICONSWIDGETS_VERSION
#  endif
#endif

#ifndef TEXTEMOTICONSWIDGETS_DISABLE_DEPRECATED_BEFORE_AND_AT
#  define TEXTEMOTICONSWIDGETS_DISABLE_DEPRECATED_BEFORE_AND_AT 0x20000
#endif

#ifdef TEXTEMOTICONSWIDGETS_DEPRECATED
#  define TEXTEMOTICONSWIDGETS_ENABLE_DEPRECATED_SINCE(major, minor) (((major<<16)|(minor<<8)) > TEXTEMOTICONSWIDGETS_DISABLE_DEPRECATED_BEFORE_AND_AT)
#else
#  define TEXTEMOTICONSWIDGETS_ENABLE_DEPRECATED_SINCE(major, minor) 0
#endif

#endif /* TEXTEMOTICONSWIDGETS_EXPORT_H */
