
#ifndef TEXTEDITTEXTTOSPEECH_EXPORT_H
#define TEXTEDITTEXTTOSPEECH_EXPORT_H

#ifdef TEXTEDITTEXTTOSPEECH_STATIC_DEFINE
#  define TEXTEDITTEXTTOSPEECH_EXPORT
#  define TEXTEDITTEXTTOSPEECH_NO_EXPORT
#else
#  ifndef TEXTEDITTEXTTOSPEECH_EXPORT
#    ifdef KF6TextEditTextToSpeech_EXPORTS
        /* We are building this library */
#      define TEXTEDITTEXTTOSPEECH_EXPORT __attribute__((visibility("default")))
#    else
        /* We are using this library */
#      define TEXTEDITTEXTTOSPEECH_EXPORT __attribute__((visibility("default")))
#    endif
#  endif

#  ifndef TEXTEDITTEXTTOSPEECH_NO_EXPORT
#    define TEXTEDITTEXTTOSPEECH_NO_EXPORT __attribute__((visibility("hidden")))
#  endif
#endif

#ifndef TEXTEDITTEXTTOSPEECH_DECL_DEPRECATED
#  define TEXTEDITTEXTTOSPEECH_DECL_DEPRECATED __attribute__ ((__deprecated__))
#endif

#ifndef TEXTEDITTEXTTOSPEECH_DECL_DEPRECATED_EXPORT
#  define TEXTEDITTEXTTOSPEECH_DECL_DEPRECATED_EXPORT TEXTEDITTEXTTOSPEECH_EXPORT TEXTEDITTEXTTOSPEECH_DECL_DEPRECATED
#endif

#ifndef TEXTEDITTEXTTOSPEECH_DECL_DEPRECATED_NO_EXPORT
#  define TEXTEDITTEXTTOSPEECH_DECL_DEPRECATED_NO_EXPORT TEXTEDITTEXTTOSPEECH_NO_EXPORT TEXTEDITTEXTTOSPEECH_DECL_DEPRECATED
#endif

/* NOLINTNEXTLINE(readability-avoid-unconditional-preprocessor-if) */
#if 0 /* DEFINE_NO_DEPRECATED */
#  ifndef TEXTEDITTEXTTOSPEECH_NO_DEPRECATED
#    define TEXTEDITTEXTTOSPEECH_NO_DEPRECATED
#  endif
#endif
#include <textedittexttospeech_version.h>

#define TEXTEDITTEXTTOSPEECH_DECL_DEPRECATED_TEXT(text) __attribute__ ((__deprecated__(text)))

#if defined(TEXTEDITTEXTTOSPEECH_NO_DEPRECATED)
#  undef TEXTEDITTEXTTOSPEECH_DEPRECATED
#  define TEXTEDITTEXTTOSPEECH_DEPRECATED_EXPORT TEXTEDITTEXTTOSPEECH_EXPORT
#  define TEXTEDITTEXTTOSPEECH_DEPRECATED_NO_EXPORT TEXTEDITTEXTTOSPEECH_NO_EXPORT
#elif defined(TEXTEDITTEXTTOSPEECH_NO_DEPRECATED_WARNINGS)
#  define TEXTEDITTEXTTOSPEECH_DEPRECATED
#  define TEXTEDITTEXTTOSPEECH_DEPRECATED_EXPORT TEXTEDITTEXTTOSPEECH_EXPORT
#  define TEXTEDITTEXTTOSPEECH_DEPRECATED_NO_EXPORT TEXTEDITTEXTTOSPEECH_NO_EXPORT
#else
#  define TEXTEDITTEXTTOSPEECH_DEPRECATED TEXTEDITTEXTTOSPEECH_DECL_DEPRECATED
#  define TEXTEDITTEXTTOSPEECH_DEPRECATED_EXPORT TEXTEDITTEXTTOSPEECH_DECL_DEPRECATED_EXPORT
#  define TEXTEDITTEXTTOSPEECH_DEPRECATED_NO_EXPORT TEXTEDITTEXTTOSPEECH_DECL_DEPRECATED_NO_EXPORT
#endif

/* No deprecated API had been removed from build */
#define TEXTEDITTEXTTOSPEECH_EXCLUDE_DEPRECATED_BEFORE_AND_AT 0

#define TEXTEDITTEXTTOSPEECH_BUILD_DEPRECATED_SINCE(major, minor) 1

#ifdef TEXTEDITTEXTTOSPEECH_NO_DEPRECATED
#  define TEXTEDITTEXTTOSPEECH_DISABLE_DEPRECATED_BEFORE_AND_AT TEXTEDITTEXTTOSPEECH_VERSION
#endif
#ifdef TEXTEDITTEXTTOSPEECH_NO_DEPRECATED_WARNINGS
#  define TEXTEDITTEXTTOSPEECH_DEPRECATED_WARNINGS_SINCE 0
#endif

#ifndef TEXTEDITTEXTTOSPEECH_DEPRECATED_WARNINGS_SINCE
#  ifdef TEXTEDITTEXTTOSPEECH_DISABLE_DEPRECATED_BEFORE_AND_AT
#    define TEXTEDITTEXTTOSPEECH_DEPRECATED_WARNINGS_SINCE TEXTEDITTEXTTOSPEECH_DISABLE_DEPRECATED_BEFORE_AND_AT
#  else
#    define TEXTEDITTEXTTOSPEECH_DEPRECATED_WARNINGS_SINCE TEXTEDITTEXTTOSPEECH_VERSION
#  endif
#endif

#ifndef TEXTEDITTEXTTOSPEECH_DISABLE_DEPRECATED_BEFORE_AND_AT
#  define TEXTEDITTEXTTOSPEECH_DISABLE_DEPRECATED_BEFORE_AND_AT 0x20000
#endif

#ifdef TEXTEDITTEXTTOSPEECH_DEPRECATED
#  define TEXTEDITTEXTTOSPEECH_ENABLE_DEPRECATED_SINCE(major, minor) (((major<<16)|(minor<<8)) > TEXTEDITTEXTTOSPEECH_DISABLE_DEPRECATED_BEFORE_AND_AT)
#else
#  define TEXTEDITTEXTTOSPEECH_ENABLE_DEPRECATED_SINCE(major, minor) 0
#endif

#endif /* TEXTEDITTEXTTOSPEECH_EXPORT_H */
