
#ifndef TEXTEMOTICONSCORE_EXPORT_H
#define TEXTEMOTICONSCORE_EXPORT_H

#ifdef TEXTEMOTICONSCORE_STATIC_DEFINE
#  define TEXTEMOTICONSCORE_EXPORT
#  define TEXTEMOTICONSCORE_NO_EXPORT
#else
#  ifndef TEXTEMOTICONSCORE_EXPORT
#    ifdef KF6TextEmoticonsCore_EXPORTS
        /* We are building this library */
#      define TEXTEMOTICONSCORE_EXPORT __attribute__((visibility("default")))
#    else
        /* We are using this library */
#      define TEXTEMOTICONSCORE_EXPORT __attribute__((visibility("default")))
#    endif
#  endif

#  ifndef TEXTEMOTICONSCORE_NO_EXPORT
#    define TEXTEMOTICONSCORE_NO_EXPORT __attribute__((visibility("hidden")))
#  endif
#endif

#ifndef TEXTEMOTICONSCORE_DECL_DEPRECATED
#  define TEXTEMOTICONSCORE_DECL_DEPRECATED __attribute__ ((__deprecated__))
#endif

#ifndef TEXTEMOTICONSCORE_DECL_DEPRECATED_EXPORT
#  define TEXTEMOTICONSCORE_DECL_DEPRECATED_EXPORT TEXTEMOTICONSCORE_EXPORT TEXTEMOTICONSCORE_DECL_DEPRECATED
#endif

#ifndef TEXTEMOTICONSCORE_DECL_DEPRECATED_NO_EXPORT
#  define TEXTEMOTICONSCORE_DECL_DEPRECATED_NO_EXPORT TEXTEMOTICONSCORE_NO_EXPORT TEXTEMOTICONSCORE_DECL_DEPRECATED
#endif

/* NOLINTNEXTLINE(readability-avoid-unconditional-preprocessor-if) */
#if 0 /* DEFINE_NO_DEPRECATED */
#  ifndef TEXTEMOTICONSCORE_NO_DEPRECATED
#    define TEXTEMOTICONSCORE_NO_DEPRECATED
#  endif
#endif
#include <textemoticonscore_version.h>

#define TEXTEMOTICONSCORE_DECL_DEPRECATED_TEXT(text) __attribute__ ((__deprecated__(text)))

#if defined(TEXTEMOTICONSCORE_NO_DEPRECATED)
#  undef TEXTEMOTICONSCORE_DEPRECATED
#  define TEXTEMOTICONSCORE_DEPRECATED_EXPORT TEXTEMOTICONSCORE_EXPORT
#  define TEXTEMOTICONSCORE_DEPRECATED_NO_EXPORT TEXTEMOTICONSCORE_NO_EXPORT
#elif defined(TEXTEMOTICONSCORE_NO_DEPRECATED_WARNINGS)
#  define TEXTEMOTICONSCORE_DEPRECATED
#  define TEXTEMOTICONSCORE_DEPRECATED_EXPORT TEXTEMOTICONSCORE_EXPORT
#  define TEXTEMOTICONSCORE_DEPRECATED_NO_EXPORT TEXTEMOTICONSCORE_NO_EXPORT
#else
#  define TEXTEMOTICONSCORE_DEPRECATED TEXTEMOTICONSCORE_DECL_DEPRECATED
#  define TEXTEMOTICONSCORE_DEPRECATED_EXPORT TEXTEMOTICONSCORE_DECL_DEPRECATED_EXPORT
#  define TEXTEMOTICONSCORE_DEPRECATED_NO_EXPORT TEXTEMOTICONSCORE_DECL_DEPRECATED_NO_EXPORT
#endif

/* No deprecated API had been removed from build */
#define TEXTEMOTICONSCORE_EXCLUDE_DEPRECATED_BEFORE_AND_AT 0

#define TEXTEMOTICONSCORE_BUILD_DEPRECATED_SINCE(major, minor) 1

#ifdef TEXTEMOTICONSCORE_NO_DEPRECATED
#  define TEXTEMOTICONSCORE_DISABLE_DEPRECATED_BEFORE_AND_AT TEXTEMOTICONSCORE_VERSION
#endif
#ifdef TEXTEMOTICONSCORE_NO_DEPRECATED_WARNINGS
#  define TEXTEMOTICONSCORE_DEPRECATED_WARNINGS_SINCE 0
#endif

#ifndef TEXTEMOTICONSCORE_DEPRECATED_WARNINGS_SINCE
#  ifdef TEXTEMOTICONSCORE_DISABLE_DEPRECATED_BEFORE_AND_AT
#    define TEXTEMOTICONSCORE_DEPRECATED_WARNINGS_SINCE TEXTEMOTICONSCORE_DISABLE_DEPRECATED_BEFORE_AND_AT
#  else
#    define TEXTEMOTICONSCORE_DEPRECATED_WARNINGS_SINCE TEXTEMOTICONSCORE_VERSION
#  endif
#endif

#ifndef TEXTEMOTICONSCORE_DISABLE_DEPRECATED_BEFORE_AND_AT
#  define TEXTEMOTICONSCORE_DISABLE_DEPRECATED_BEFORE_AND_AT 0x20000
#endif

#ifdef TEXTEMOTICONSCORE_DEPRECATED
#  define TEXTEMOTICONSCORE_ENABLE_DEPRECATED_SINCE(major, minor) (((major<<16)|(minor<<8)) > TEXTEMOTICONSCORE_DISABLE_DEPRECATED_BEFORE_AND_AT)
#else
#  define TEXTEMOTICONSCORE_ENABLE_DEPRECATED_SINCE(major, minor) 0
#endif

#endif /* TEXTEMOTICONSCORE_EXPORT_H */
