
#ifndef TEXTAUTOCORRECTIONCORE_EXPORT_H
#define TEXTAUTOCORRECTIONCORE_EXPORT_H

#ifdef TEXTAUTOCORRECTIONCORE_STATIC_DEFINE
#  define TEXTAUTOCORRECTIONCORE_EXPORT
#  define TEXTAUTOCORRECTIONCORE_NO_EXPORT
#else
#  ifndef TEXTAUTOCORRECTIONCORE_EXPORT
#    ifdef KF6TextAutoCorrectionCore_EXPORTS
        /* We are building this library */
#      define TEXTAUTOCORRECTIONCORE_EXPORT __attribute__((visibility("default")))
#    else
        /* We are using this library */
#      define TEXTAUTOCORRECTIONCORE_EXPORT __attribute__((visibility("default")))
#    endif
#  endif

#  ifndef TEXTAUTOCORRECTIONCORE_NO_EXPORT
#    define TEXTAUTOCORRECTIONCORE_NO_EXPORT __attribute__((visibility("hidden")))
#  endif
#endif

#ifndef TEXTAUTOCORRECTIONCORE_DECL_DEPRECATED
#  define TEXTAUTOCORRECTIONCORE_DECL_DEPRECATED __attribute__ ((__deprecated__))
#endif

#ifndef TEXTAUTOCORRECTIONCORE_DECL_DEPRECATED_EXPORT
#  define TEXTAUTOCORRECTIONCORE_DECL_DEPRECATED_EXPORT TEXTAUTOCORRECTIONCORE_EXPORT TEXTAUTOCORRECTIONCORE_DECL_DEPRECATED
#endif

#ifndef TEXTAUTOCORRECTIONCORE_DECL_DEPRECATED_NO_EXPORT
#  define TEXTAUTOCORRECTIONCORE_DECL_DEPRECATED_NO_EXPORT TEXTAUTOCORRECTIONCORE_NO_EXPORT TEXTAUTOCORRECTIONCORE_DECL_DEPRECATED
#endif

/* NOLINTNEXTLINE(readability-avoid-unconditional-preprocessor-if) */
#if 0 /* DEFINE_NO_DEPRECATED */
#  ifndef TEXTAUTOCORRECTIONCORE_NO_DEPRECATED
#    define TEXTAUTOCORRECTIONCORE_NO_DEPRECATED
#  endif
#endif
#include <textautocorrectioncore_version.h>

#define TEXTAUTOCORRECTIONCORE_DECL_DEPRECATED_TEXT(text) __attribute__ ((__deprecated__(text)))

#if defined(TEXTAUTOCORRECTIONCORE_NO_DEPRECATED)
#  undef TEXTAUTOCORRECTIONCORE_DEPRECATED
#  define TEXTAUTOCORRECTIONCORE_DEPRECATED_EXPORT TEXTAUTOCORRECTIONCORE_EXPORT
#  define TEXTAUTOCORRECTIONCORE_DEPRECATED_NO_EXPORT TEXTAUTOCORRECTIONCORE_NO_EXPORT
#elif defined(TEXTAUTOCORRECTIONCORE_NO_DEPRECATED_WARNINGS)
#  define TEXTAUTOCORRECTIONCORE_DEPRECATED
#  define TEXTAUTOCORRECTIONCORE_DEPRECATED_EXPORT TEXTAUTOCORRECTIONCORE_EXPORT
#  define TEXTAUTOCORRECTIONCORE_DEPRECATED_NO_EXPORT TEXTAUTOCORRECTIONCORE_NO_EXPORT
#else
#  define TEXTAUTOCORRECTIONCORE_DEPRECATED TEXTAUTOCORRECTIONCORE_DECL_DEPRECATED
#  define TEXTAUTOCORRECTIONCORE_DEPRECATED_EXPORT TEXTAUTOCORRECTIONCORE_DECL_DEPRECATED_EXPORT
#  define TEXTAUTOCORRECTIONCORE_DEPRECATED_NO_EXPORT TEXTAUTOCORRECTIONCORE_DECL_DEPRECATED_NO_EXPORT
#endif

/* No deprecated API had been removed from build */
#define TEXTAUTOCORRECTIONCORE_EXCLUDE_DEPRECATED_BEFORE_AND_AT 0

#define TEXTAUTOCORRECTIONCORE_BUILD_DEPRECATED_SINCE(major, minor) 1

#ifdef TEXTAUTOCORRECTIONCORE_NO_DEPRECATED
#  define TEXTAUTOCORRECTIONCORE_DISABLE_DEPRECATED_BEFORE_AND_AT TEXTAUTOCORRECTIONCORE_VERSION
#endif
#ifdef TEXTAUTOCORRECTIONCORE_NO_DEPRECATED_WARNINGS
#  define TEXTAUTOCORRECTIONCORE_DEPRECATED_WARNINGS_SINCE 0
#endif

#ifndef TEXTAUTOCORRECTIONCORE_DEPRECATED_WARNINGS_SINCE
#  ifdef TEXTAUTOCORRECTIONCORE_DISABLE_DEPRECATED_BEFORE_AND_AT
#    define TEXTAUTOCORRECTIONCORE_DEPRECATED_WARNINGS_SINCE TEXTAUTOCORRECTIONCORE_DISABLE_DEPRECATED_BEFORE_AND_AT
#  else
#    define TEXTAUTOCORRECTIONCORE_DEPRECATED_WARNINGS_SINCE TEXTAUTOCORRECTIONCORE_VERSION
#  endif
#endif

#ifndef TEXTAUTOCORRECTIONCORE_DISABLE_DEPRECATED_BEFORE_AND_AT
#  define TEXTAUTOCORRECTIONCORE_DISABLE_DEPRECATED_BEFORE_AND_AT 0x20000
#endif

#ifdef TEXTAUTOCORRECTIONCORE_DEPRECATED
#  define TEXTAUTOCORRECTIONCORE_ENABLE_DEPRECATED_SINCE(major, minor) (((major<<16)|(minor<<8)) > TEXTAUTOCORRECTIONCORE_DISABLE_DEPRECATED_BEFORE_AND_AT)
#else
#  define TEXTAUTOCORRECTIONCORE_ENABLE_DEPRECATED_SINCE(major, minor) 0
#endif

#endif /* TEXTAUTOCORRECTIONCORE_EXPORT_H */
