
#ifndef TEXTSPEECHTOTEXT_EXPORT_H
#define TEXTSPEECHTOTEXT_EXPORT_H

#ifdef TEXTSPEECHTOTEXT_STATIC_DEFINE
#  define TEXTSPEECHTOTEXT_EXPORT
#  define TEXTSPEECHTOTEXT_NO_EXPORT
#else
#  ifndef TEXTSPEECHTOTEXT_EXPORT
#    ifdef KF6TextSpeechToText_EXPORTS
        /* We are building this library */
#      define TEXTSPEECHTOTEXT_EXPORT __attribute__((visibility("default")))
#    else
        /* We are using this library */
#      define TEXTSPEECHTOTEXT_EXPORT __attribute__((visibility("default")))
#    endif
#  endif

#  ifndef TEXTSPEECHTOTEXT_NO_EXPORT
#    define TEXTSPEECHTOTEXT_NO_EXPORT __attribute__((visibility("hidden")))
#  endif
#endif

#ifndef TEXTSPEECHTOTEXT_DECL_DEPRECATED
#  define TEXTSPEECHTOTEXT_DECL_DEPRECATED __attribute__ ((__deprecated__))
#endif

#ifndef TEXTSPEECHTOTEXT_DECL_DEPRECATED_EXPORT
#  define TEXTSPEECHTOTEXT_DECL_DEPRECATED_EXPORT TEXTSPEECHTOTEXT_EXPORT TEXTSPEECHTOTEXT_DECL_DEPRECATED
#endif

#ifndef TEXTSPEECHTOTEXT_DECL_DEPRECATED_NO_EXPORT
#  define TEXTSPEECHTOTEXT_DECL_DEPRECATED_NO_EXPORT TEXTSPEECHTOTEXT_NO_EXPORT TEXTSPEECHTOTEXT_DECL_DEPRECATED
#endif

/* NOLINTNEXTLINE(readability-avoid-unconditional-preprocessor-if) */
#if 0 /* DEFINE_NO_DEPRECATED */
#  ifndef TEXTSPEECHTOTEXT_NO_DEPRECATED
#    define TEXTSPEECHTOTEXT_NO_DEPRECATED
#  endif
#endif
#include <textspeechtotext_version.h>

#define TEXTSPEECHTOTEXT_DECL_DEPRECATED_TEXT(text) __attribute__ ((__deprecated__(text)))

#if defined(TEXTSPEECHTOTEXT_NO_DEPRECATED)
#  undef TEXTSPEECHTOTEXT_DEPRECATED
#  define TEXTSPEECHTOTEXT_DEPRECATED_EXPORT TEXTSPEECHTOTEXT_EXPORT
#  define TEXTSPEECHTOTEXT_DEPRECATED_NO_EXPORT TEXTSPEECHTOTEXT_NO_EXPORT
#elif defined(TEXTSPEECHTOTEXT_NO_DEPRECATED_WARNINGS)
#  define TEXTSPEECHTOTEXT_DEPRECATED
#  define TEXTSPEECHTOTEXT_DEPRECATED_EXPORT TEXTSPEECHTOTEXT_EXPORT
#  define TEXTSPEECHTOTEXT_DEPRECATED_NO_EXPORT TEXTSPEECHTOTEXT_NO_EXPORT
#else
#  define TEXTSPEECHTOTEXT_DEPRECATED TEXTSPEECHTOTEXT_DECL_DEPRECATED
#  define TEXTSPEECHTOTEXT_DEPRECATED_EXPORT TEXTSPEECHTOTEXT_DECL_DEPRECATED_EXPORT
#  define TEXTSPEECHTOTEXT_DEPRECATED_NO_EXPORT TEXTSPEECHTOTEXT_DECL_DEPRECATED_NO_EXPORT
#endif

/* No deprecated API had been removed from build */
#define TEXTSPEECHTOTEXT_EXCLUDE_DEPRECATED_BEFORE_AND_AT 0

#define TEXTSPEECHTOTEXT_BUILD_DEPRECATED_SINCE(major, minor) 1

#ifdef TEXTSPEECHTOTEXT_NO_DEPRECATED
#  define TEXTSPEECHTOTEXT_DISABLE_DEPRECATED_BEFORE_AND_AT TEXTSPEECHTOTEXT_VERSION
#endif
#ifdef TEXTSPEECHTOTEXT_NO_DEPRECATED_WARNINGS
#  define TEXTSPEECHTOTEXT_DEPRECATED_WARNINGS_SINCE 0
#endif

#ifndef TEXTSPEECHTOTEXT_DEPRECATED_WARNINGS_SINCE
#  ifdef TEXTSPEECHTOTEXT_DISABLE_DEPRECATED_BEFORE_AND_AT
#    define TEXTSPEECHTOTEXT_DEPRECATED_WARNINGS_SINCE TEXTSPEECHTOTEXT_DISABLE_DEPRECATED_BEFORE_AND_AT
#  else
#    define TEXTSPEECHTOTEXT_DEPRECATED_WARNINGS_SINCE TEXTSPEECHTOTEXT_VERSION
#  endif
#endif

#ifndef TEXTSPEECHTOTEXT_DISABLE_DEPRECATED_BEFORE_AND_AT
#  define TEXTSPEECHTOTEXT_DISABLE_DEPRECATED_BEFORE_AND_AT 0x20000
#endif

#ifdef TEXTSPEECHTOTEXT_DEPRECATED
#  define TEXTSPEECHTOTEXT_ENABLE_DEPRECATED_SINCE(major, minor) (((major<<16)|(minor<<8)) > TEXTSPEECHTOTEXT_DISABLE_DEPRECATED_BEFORE_AND_AT)
#else
#  define TEXTSPEECHTOTEXT_ENABLE_DEPRECATED_SINCE(major, minor) 0
#endif

#endif /* TEXTSPEECHTOTEXT_EXPORT_H */
