// This file was generated by ecm_setup_version(): DO NOT EDIT!

#ifndef TEXTCUSTOMEDITOR_VERSION_H
#define TEXTCUSTOMEDITOR_VERSION_H

#define TEXTCUSTOMEDITOR_VERSION_STRING "2.1.1"
#define TEXTCUSTOMEDITOR_VERSION_MAJOR 2
#define TEXTCUSTOMEDITOR_VERSION_MINOR 1
#define TEXTCUSTOMEDITOR_VERSION_PATCH 1
#define TEXTCUSTOMEDITOR_VERSION ((2<<16)|(1<<8)|(1))

#endif
