
#ifndef TEXTCUSTOMEDITOR_EXPORT_H
#define TEXTCUSTOMEDITOR_EXPORT_H

#ifdef TEXTCUSTOMEDITOR_STATIC_DEFINE
#  define TEXTCUSTOMEDITOR_EXPORT
#  define TEXTCUSTOMEDITOR_NO_EXPORT
#else
#  ifndef TEXTCUSTOMEDITOR_EXPORT
#    ifdef KF6TextCustomEditor_EXPORTS
        /* We are building this library */
#      define TEXTCUSTOMEDITOR_EXPORT __attribute__((visibility("default")))
#    else
        /* We are using this library */
#      define TEXTCUSTOMEDITOR_EXPORT __attribute__((visibility("default")))
#    endif
#  endif

#  ifndef TEXTCUSTOMEDITOR_NO_EXPORT
#    define TEXTCUSTOMEDITOR_NO_EXPORT __attribute__((visibility("hidden")))
#  endif
#endif

#ifndef TEXTCUSTOMEDITOR_DECL_DEPRECATED
#  define TEXTCUSTOMEDITOR_DECL_DEPRECATED __attribute__ ((__deprecated__))
#endif

#ifndef TEXTCUSTOMEDITOR_DECL_DEPRECATED_EXPORT
#  define TEXTCUSTOMEDITOR_DECL_DEPRECATED_EXPORT TEXTCUSTOMEDITOR_EXPORT TEXTCUSTOMEDITOR_DECL_DEPRECATED
#endif

#ifndef TEXTCUSTOMEDITOR_DECL_DEPRECATED_NO_EXPORT
#  define TEXTCUSTOMEDITOR_DECL_DEPRECATED_NO_EXPORT TEXTCUSTOMEDITOR_NO_EXPORT TEXTCUSTOMEDITOR_DECL_DEPRECATED
#endif

/* NOLINTNEXTLINE(readability-avoid-unconditional-preprocessor-if) */
#if 0 /* DEFINE_NO_DEPRECATED */
#  ifndef TEXTCUSTOMEDITOR_NO_DEPRECATED
#    define TEXTCUSTOMEDITOR_NO_DEPRECATED
#  endif
#endif
#include <textcustomeditor_version.h>

#define TEXTCUSTOMEDITOR_DECL_DEPRECATED_TEXT(text) __attribute__ ((__deprecated__(text)))

#if defined(TEXTCUSTOMEDITOR_NO_DEPRECATED)
#  undef TEXTCUSTOMEDITOR_DEPRECATED
#  define TEXTCUSTOMEDITOR_DEPRECATED_EXPORT TEXTCUSTOMEDITOR_EXPORT
#  define TEXTCUSTOMEDITOR_DEPRECATED_NO_EXPORT TEXTCUSTOMEDITOR_NO_EXPORT
#elif defined(TEXTCUSTOMEDITOR_NO_DEPRECATED_WARNINGS)
#  define TEXTCUSTOMEDITOR_DEPRECATED
#  define TEXTCUSTOMEDITOR_DEPRECATED_EXPORT TEXTCUSTOMEDITOR_EXPORT
#  define TEXTCUSTOMEDITOR_DEPRECATED_NO_EXPORT TEXTCUSTOMEDITOR_NO_EXPORT
#else
#  define TEXTCUSTOMEDITOR_DEPRECATED TEXTCUSTOMEDITOR_DECL_DEPRECATED
#  define TEXTCUSTOMEDITOR_DEPRECATED_EXPORT TEXTCUSTOMEDITOR_DECL_DEPRECATED_EXPORT
#  define TEXTCUSTOMEDITOR_DEPRECATED_NO_EXPORT TEXTCUSTOMEDITOR_DECL_DEPRECATED_NO_EXPORT
#endif

/* No deprecated API had been removed from build */
#define TEXTCUSTOMEDITOR_EXCLUDE_DEPRECATED_BEFORE_AND_AT 0

#define TEXTCUSTOMEDITOR_BUILD_DEPRECATED_SINCE(major, minor) 1

#ifdef TEXTCUSTOMEDITOR_NO_DEPRECATED
#  define TEXTCUSTOMEDITOR_DISABLE_DEPRECATED_BEFORE_AND_AT TEXTCUSTOMEDITOR_VERSION
#endif
#ifdef TEXTCUSTOMEDITOR_NO_DEPRECATED_WARNINGS
#  define TEXTCUSTOMEDITOR_DEPRECATED_WARNINGS_SINCE 0
#endif

#ifndef TEXTCUSTOMEDITOR_DEPRECATED_WARNINGS_SINCE
#  ifdef TEXTCUSTOMEDITOR_DISABLE_DEPRECATED_BEFORE_AND_AT
#    define TEXTCUSTOMEDITOR_DEPRECATED_WARNINGS_SINCE TEXTCUSTOMEDITOR_DISABLE_DEPRECATED_BEFORE_AND_AT
#  else
#    define TEXTCUSTOMEDITOR_DEPRECATED_WARNINGS_SINCE TEXTCUSTOMEDITOR_VERSION
#  endif
#endif

#ifndef TEXTCUSTOMEDITOR_DISABLE_DEPRECATED_BEFORE_AND_AT
#  define TEXTCUSTOMEDITOR_DISABLE_DEPRECATED_BEFORE_AND_AT 0x20000
#endif

#ifdef TEXTCUSTOMEDITOR_DEPRECATED
#  define TEXTCUSTOMEDITOR_ENABLE_DEPRECATED_SINCE(major, minor) (((major<<16)|(minor<<8)) > TEXTCUSTOMEDITOR_DISABLE_DEPRECATED_BEFORE_AND_AT)
#else
#  define TEXTCUSTOMEDITOR_ENABLE_DEPRECATED_SINCE(major, minor) 0
#endif

#endif /* TEXTCUSTOMEDITOR_EXPORT_H */
