
#ifndef TEXTAUTOCORRECTIONWIDGETS_EXPORT_H
#define TEXTAUTOCORRECTIONWIDGETS_EXPORT_H

#ifdef TEXTAUTOCORRECTIONWIDGETS_STATIC_DEFINE
#  define TEXTAUTOCORRECTIONWIDGETS_EXPORT
#  define TEXTAUTOCORRECTIONWIDGETS_NO_EXPORT
#else
#  ifndef TEXTAUTOCORRECTIONWIDGETS_EXPORT
#    ifdef KF6TextAutoCorrectionWidgets_EXPORTS
        /* We are building this library */
#      define TEXTAUTOCORRECTIONWIDGETS_EXPORT __attribute__((visibility("default")))
#    else
        /* We are using this library */
#      define TEXTAUTOCORRECTIONWIDGETS_EXPORT __attribute__((visibility("default")))
#    endif
#  endif

#  ifndef TEXTAUTOCORRECTIONWIDGETS_NO_EXPORT
#    define TEXTAUTOCORRECTIONWIDGETS_NO_EXPORT __attribute__((visibility("hidden")))
#  endif
#endif

#ifndef TEXTAUTOCORRECTIONWIDGETS_DECL_DEPRECATED
#  define TEXTAUTOCORRECTIONWIDGETS_DECL_DEPRECATED __attribute__ ((__deprecated__))
#endif

#ifndef TEXTAUTOCORRECTIONWIDGETS_DECL_DEPRECATED_EXPORT
#  define TEXTAUTOCORRECTIONWIDGETS_DECL_DEPRECATED_EXPORT TEXTAUTOCORRECTIONWIDGETS_EXPORT TEXTAUTOCORRECTIONWIDGETS_DECL_DEPRECATED
#endif

#ifndef TEXTAUTOCORRECTIONWIDGETS_DECL_DEPRECATED_NO_EXPORT
#  define TEXTAUTOCORRECTIONWIDGETS_DECL_DEPRECATED_NO_EXPORT TEXTAUTOCORRECTIONWIDGETS_NO_EXPORT TEXTAUTOCORRECTIONWIDGETS_DECL_DEPRECATED
#endif

/* NOLINTNEXTLINE(readability-avoid-unconditional-preprocessor-if) */
#if 0 /* DEFINE_NO_DEPRECATED */
#  ifndef TEXTAUTOCORRECTIONWIDGETS_NO_DEPRECATED
#    define TEXTAUTOCORRECTIONWIDGETS_NO_DEPRECATED
#  endif
#endif
#include <textautocorrectionwidgets_version.h>

#define TEXTAUTOCORRECTIONWIDGETS_DECL_DEPRECATED_TEXT(text) __attribute__ ((__deprecated__(text)))

#if defined(TEXTAUTOCORRECTIONWIDGETS_NO_DEPRECATED)
#  undef TEXTAUTOCORRECTIONWIDGETS_DEPRECATED
#  define TEXTAUTOCORRECTIONWIDGETS_DEPRECATED_EXPORT TEXTAUTOCORRECTIONWIDGETS_EXPORT
#  define TEXTAUTOCORRECTIONWIDGETS_DEPRECATED_NO_EXPORT TEXTAUTOCORRECTIONWIDGETS_NO_EXPORT
#elif defined(TEXTAUTOCORRECTIONWIDGETS_NO_DEPRECATED_WARNINGS)
#  define TEXTAUTOCORRECTIONWIDGETS_DEPRECATED
#  define TEXTAUTOCORRECTIONWIDGETS_DEPRECATED_EXPORT TEXTAUTOCORRECTIONWIDGETS_EXPORT
#  define TEXTAUTOCORRECTIONWIDGETS_DEPRECATED_NO_EXPORT TEXTAUTOCORRECTIONWIDGETS_NO_EXPORT
#else
#  define TEXTAUTOCORRECTIONWIDGETS_DEPRECATED TEXTAUTOCORRECTIONWIDGETS_DECL_DEPRECATED
#  define TEXTAUTOCORRECTIONWIDGETS_DEPRECATED_EXPORT TEXTAUTOCORRECTIONWIDGETS_DECL_DEPRECATED_EXPORT
#  define TEXTAUTOCORRECTIONWIDGETS_DEPRECATED_NO_EXPORT TEXTAUTOCORRECTIONWIDGETS_DECL_DEPRECATED_NO_EXPORT
#endif

/* No deprecated API had been removed from build */
#define TEXTAUTOCORRECTIONWIDGETS_EXCLUDE_DEPRECATED_BEFORE_AND_AT 0

#define TEXTAUTOCORRECTIONWIDGETS_BUILD_DEPRECATED_SINCE(major, minor) 1

#ifdef TEXTAUTOCORRECTIONWIDGETS_NO_DEPRECATED
#  define TEXTAUTOCORRECTIONWIDGETS_DISABLE_DEPRECATED_BEFORE_AND_AT TEXTAUTOCORRECTIONWIDGETS_VERSION
#endif
#ifdef TEXTAUTOCORRECTIONWIDGETS_NO_DEPRECATED_WARNINGS
#  define TEXTAUTOCORRECTIONWIDGETS_DEPRECATED_WARNINGS_SINCE 0
#endif

#ifndef TEXTAUTOCORRECTIONWIDGETS_DEPRECATED_WARNINGS_SINCE
#  ifdef TEXTAUTOCORRECTIONWIDGETS_DISABLE_DEPRECATED_BEFORE_AND_AT
#    define TEXTAUTOCORRECTIONWIDGETS_DEPRECATED_WARNINGS_SINCE TEXTAUTOCORRECTIONWIDGETS_DISABLE_DEPRECATED_BEFORE_AND_AT
#  else
#    define TEXTAUTOCORRECTIONWIDGETS_DEPRECATED_WARNINGS_SINCE TEXTAUTOCORRECTIONWIDGETS_VERSION
#  endif
#endif

#ifndef TEXTAUTOCORRECTIONWIDGETS_DISABLE_DEPRECATED_BEFORE_AND_AT
#  define TEXTAUTOCORRECTIONWIDGETS_DISABLE_DEPRECATED_BEFORE_AND_AT 0x20000
#endif

#ifdef TEXTAUTOCORRECTIONWIDGETS_DEPRECATED
#  define TEXTAUTOCORRECTIONWIDGETS_ENABLE_DEPRECATED_SINCE(major, minor) (((major<<16)|(minor<<8)) > TEXTAUTOCORRECTIONWIDGETS_DISABLE_DEPRECATED_BEFORE_AND_AT)
#else
#  define TEXTAUTOCORRECTIONWIDGETS_ENABLE_DEPRECATED_SINCE(major, minor) 0
#endif

#endif /* TEXTAUTOCORRECTIONWIDGETS_EXPORT_H */
