
#ifndef TEXTAUTOGENERATETEXTMCPPROTOCOLWIDGETS_EXPORT_H
#define TEXTAUTOGENERATETEXTMCPPROTOCOLWIDGETS_EXPORT_H

#ifdef TEXTAUTOGENERATETEXTMCPPROTOCOLWIDGETS_STATIC_DEFINE
#  define TEXTAUTOGENERATETEXTMCPPROTOCOLWIDGETS_EXPORT
#  define TEXTAUTOGENERATETEXTMCPPROTOCOLWIDGETS_NO_EXPORT
#else
#  ifndef TEXTAUTOGENERATETEXTMCPPROTOCOLWIDGETS_EXPORT
#    ifdef KF6TextAutoGenerateTextMcpProtocolWidgets_EXPORTS
        /* We are building this library */
#      define TEXTAUTOGENERATETEXTMCPPROTOCOLWIDGETS_EXPORT __attribute__((visibility("default")))
#    else
        /* We are using this library */
#      define TEXTAUTOGENERATETEXTMCPPROTOCOLWIDGETS_EXPORT __attribute__((visibility("default")))
#    endif
#  endif

#  ifndef TEXTAUTOGENERATETEXTMCPPROTOCOLWIDGETS_NO_EXPORT
#    define TEXTAUTOGENERATETEXTMCPPROTOCOLWIDGETS_NO_EXPORT __attribute__((visibility("hidden")))
#  endif
#endif

#ifndef TEXTAUTOGENERATETEXTMCPPROTOCOLWIDGETS_DEPRECATED
#  define TEXTAUTOGENERATETEXTMCPPROTOCOLWIDGETS_DEPRECATED __attribute__ ((__deprecated__))
#endif

#ifndef TEXTAUTOGENERATETEXTMCPPROTOCOLWIDGETS_DEPRECATED_EXPORT
#  define TEXTAUTOGENERATETEXTMCPPROTOCOLWIDGETS_DEPRECATED_EXPORT TEXTAUTOGENERATETEXTMCPPROTOCOLWIDGETS_EXPORT TEXTAUTOGENERATETEXTMCPPROTOCOLWIDGETS_DEPRECATED
#endif

#ifndef TEXTAUTOGENERATETEXTMCPPROTOCOLWIDGETS_DEPRECATED_NO_EXPORT
#  define TEXTAUTOGENERATETEXTMCPPROTOCOLWIDGETS_DEPRECATED_NO_EXPORT TEXTAUTOGENERATETEXTMCPPROTOCOLWIDGETS_NO_EXPORT TEXTAUTOGENERATETEXTMCPPROTOCOLWIDGETS_DEPRECATED
#endif

/* NOLINTNEXTLINE(readability-avoid-unconditional-preprocessor-if) */
#if 0 /* DEFINE_NO_DEPRECATED */
#  ifndef TEXTAUTOGENERATETEXTMCPPROTOCOLWIDGETS_NO_DEPRECATED
#    define TEXTAUTOGENERATETEXTMCPPROTOCOLWIDGETS_NO_DEPRECATED
#  endif
#endif

#endif /* TEXTAUTOGENERATETEXTMCPPROTOCOLWIDGETS_EXPORT_H */
