
#ifndef TEXTAUTOGENERATETEXTMCPPROTOCOLCORE_EXPORT_H
#define TEXTAUTOGENERATETEXTMCPPROTOCOLCORE_EXPORT_H

#ifdef TEXTAUTOGENERATETEXTMCPPROTOCOLCORE_STATIC_DEFINE
#  define TEXTAUTOGENERATETEXTMCPPROTOCOLCORE_EXPORT
#  define TEXTAUTOGENERATETEXTMCPPROTOCOLCORE_NO_EXPORT
#else
#  ifndef TEXTAUTOGENERATETEXTMCPPROTOCOLCORE_EXPORT
#    ifdef KF6TextAutoGenerateTextMcpProtocolCore_EXPORTS
        /* We are building this library */
#      define TEXTAUTOGENERATETEXTMCPPROTOCOLCORE_EXPORT __attribute__((visibility("default")))
#    else
        /* We are using this library */
#      define TEXTAUTOGENERATETEXTMCPPROTOCOLCORE_EXPORT __attribute__((visibility("default")))
#    endif
#  endif

#  ifndef TEXTAUTOGENERATETEXTMCPPROTOCOLCORE_NO_EXPORT
#    define TEXTAUTOGENERATETEXTMCPPROTOCOLCORE_NO_EXPORT __attribute__((visibility("hidden")))
#  endif
#endif

#ifndef TEXTAUTOGENERATETEXTMCPPROTOCOLCORE_DEPRECATED
#  define TEXTAUTOGENERATETEXTMCPPROTOCOLCORE_DEPRECATED __attribute__ ((__deprecated__))
#endif

#ifndef TEXTAUTOGENERATETEXTMCPPROTOCOLCORE_DEPRECATED_EXPORT
#  define TEXTAUTOGENERATETEXTMCPPROTOCOLCORE_DEPRECATED_EXPORT TEXTAUTOGENERATETEXTMCPPROTOCOLCORE_EXPORT TEXTAUTOGENERATETEXTMCPPROTOCOLCORE_DEPRECATED
#endif

#ifndef TEXTAUTOGENERATETEXTMCPPROTOCOLCORE_DEPRECATED_NO_EXPORT
#  define TEXTAUTOGENERATETEXTMCPPROTOCOLCORE_DEPRECATED_NO_EXPORT TEXTAUTOGENERATETEXTMCPPROTOCOLCORE_NO_EXPORT TEXTAUTOGENERATETEXTMCPPROTOCOLCORE_DEPRECATED
#endif

/* NOLINTNEXTLINE(readability-avoid-unconditional-preprocessor-if) */
#if 0 /* DEFINE_NO_DEPRECATED */
#  ifndef TEXTAUTOGENERATETEXTMCPPROTOCOLCORE_NO_DEPRECATED
#    define TEXTAUTOGENERATETEXTMCPPROTOCOLCORE_NO_DEPRECATED
#  endif
#endif

#endif /* TEXTAUTOGENERATETEXTMCPPROTOCOLCORE_EXPORT_H */
