
#ifndef TEXTUTILS_EXPORT_H
#define TEXTUTILS_EXPORT_H

#ifdef TEXTUTILS_STATIC_DEFINE
#  define TEXTUTILS_EXPORT
#  define TEXTUTILS_NO_EXPORT
#else
#  ifndef TEXTUTILS_EXPORT
#    ifdef KF6TextUtils_EXPORTS
        /* We are building this library */
#      define TEXTUTILS_EXPORT __attribute__((visibility("default")))
#    else
        /* We are using this library */
#      define TEXTUTILS_EXPORT __attribute__((visibility("default")))
#    endif
#  endif

#  ifndef TEXTUTILS_NO_EXPORT
#    define TEXTUTILS_NO_EXPORT __attribute__((visibility("hidden")))
#  endif
#endif

#ifndef TEXTUTILS_DECL_DEPRECATED
#  define TEXTUTILS_DECL_DEPRECATED __attribute__ ((__deprecated__))
#endif

#ifndef TEXTUTILS_DECL_DEPRECATED_EXPORT
#  define TEXTUTILS_DECL_DEPRECATED_EXPORT TEXTUTILS_EXPORT TEXTUTILS_DECL_DEPRECATED
#endif

#ifndef TEXTUTILS_DECL_DEPRECATED_NO_EXPORT
#  define TEXTUTILS_DECL_DEPRECATED_NO_EXPORT TEXTUTILS_NO_EXPORT TEXTUTILS_DECL_DEPRECATED
#endif

/* NOLINTNEXTLINE(readability-avoid-unconditional-preprocessor-if) */
#if 0 /* DEFINE_NO_DEPRECATED */
#  ifndef TEXTUTILS_NO_DEPRECATED
#    define TEXTUTILS_NO_DEPRECATED
#  endif
#endif
#include <textutils_version.h>

#define TEXTUTILS_DECL_DEPRECATED_TEXT(text) __attribute__ ((__deprecated__(text)))

#if defined(TEXTUTILS_NO_DEPRECATED)
#  undef TEXTUTILS_DEPRECATED
#  define TEXTUTILS_DEPRECATED_EXPORT TEXTUTILS_EXPORT
#  define TEXTUTILS_DEPRECATED_NO_EXPORT TEXTUTILS_NO_EXPORT
#elif defined(TEXTUTILS_NO_DEPRECATED_WARNINGS)
#  define TEXTUTILS_DEPRECATED
#  define TEXTUTILS_DEPRECATED_EXPORT TEXTUTILS_EXPORT
#  define TEXTUTILS_DEPRECATED_NO_EXPORT TEXTUTILS_NO_EXPORT
#else
#  define TEXTUTILS_DEPRECATED TEXTUTILS_DECL_DEPRECATED
#  define TEXTUTILS_DEPRECATED_EXPORT TEXTUTILS_DECL_DEPRECATED_EXPORT
#  define TEXTUTILS_DEPRECATED_NO_EXPORT TEXTUTILS_DECL_DEPRECATED_NO_EXPORT
#endif

/* No deprecated API had been removed from build */
#define TEXTUTILS_EXCLUDE_DEPRECATED_BEFORE_AND_AT 0

#define TEXTUTILS_BUILD_DEPRECATED_SINCE(major, minor) 1

#ifdef TEXTUTILS_NO_DEPRECATED
#  define TEXTUTILS_DISABLE_DEPRECATED_BEFORE_AND_AT TEXTUTILS_VERSION
#endif
#ifdef TEXTUTILS_NO_DEPRECATED_WARNINGS
#  define TEXTUTILS_DEPRECATED_WARNINGS_SINCE 0
#endif

#ifndef TEXTUTILS_DEPRECATED_WARNINGS_SINCE
#  ifdef TEXTUTILS_DISABLE_DEPRECATED_BEFORE_AND_AT
#    define TEXTUTILS_DEPRECATED_WARNINGS_SINCE TEXTUTILS_DISABLE_DEPRECATED_BEFORE_AND_AT
#  else
#    define TEXTUTILS_DEPRECATED_WARNINGS_SINCE TEXTUTILS_VERSION
#  endif
#endif

#ifndef TEXTUTILS_DISABLE_DEPRECATED_BEFORE_AND_AT
#  define TEXTUTILS_DISABLE_DEPRECATED_BEFORE_AND_AT 0x20000
#endif

#ifdef TEXTUTILS_DEPRECATED
#  define TEXTUTILS_ENABLE_DEPRECATED_SINCE(major, minor) (((major<<16)|(minor<<8)) > TEXTUTILS_DISABLE_DEPRECATED_BEFORE_AND_AT)
#else
#  define TEXTUTILS_ENABLE_DEPRECATED_SINCE(major, minor) 0
#endif

#endif /* TEXTUTILS_EXPORT_H */
