/*
  SPDX-FileCopyrightText: 2026 Laurent Montel <montel@kde.org>

  SPDX-License-Identifier: GPL-2.0-or-later
*/
#pragma once
#include "textautogeneratetextmcpprotocolcore_export.h"
#include <QByteArray>
#include <QString>
#include <TextAutoGenerateTextMcpProtocolCore/McpProtocolAnnotations>
#include <TextAutoGenerateTextMcpProtocolCore/McpProtocolBlobResourceContents>
#include <TextAutoGenerateTextMcpProtocolCore/McpProtocolTextResourceContents>
#include <TextAutoGenerateTextMcpProtocolCore/McpProtocolUtils>
class QDebug;
class QJsonObject;
namespace TextAutoGenerateTextMcpProtocolCore
{
class TEXTAUTOGENERATETEXTMCPPROTOCOLCORE_EXPORT McpProtocolEmbeddedResource
{
public:
    /*!
     */
    McpProtocolEmbeddedResource();
    /*!
     */
    ~McpProtocolEmbeddedResource();

    /*!
     */
    [[nodiscard]] static QByteArray type();

    /*!
     */
    [[nodiscard]] bool operator==(const McpProtocolEmbeddedResource &other) const;

    /*!
     */
    [[nodiscard]] static McpProtocolEmbeddedResource fromJson(const QJsonObject &obj);
    /*!
     */
    [[nodiscard]] static QJsonObject toJson(const McpProtocolEmbeddedResource &image);

    /*!
     */
    [[nodiscard]] std::optional<McpProtocolMeta> meta() const;
    /*!
     */
    void setMeta(std::optional<McpProtocolMeta> newMeta);

    /*!
     */
    [[nodiscard]] std::optional<McpProtocolAnnotations> annotations() const;
    /*!
     */
    void setAnnotations(std::optional<McpProtocolAnnotations> newAnnotations);

    /*!
     */
    [[nodiscard]] McpProtocolUtils::EmbeddedResourceResource resource() const;
    /*!
     */
    void setResource(const McpProtocolUtils::EmbeddedResourceResource &newResource);

private:
    std::optional<McpProtocolAnnotations> mAnnotations;
    McpProtocolUtils::EmbeddedResourceResource mResource;
    std::optional<McpProtocolMeta> mMeta;
};
}
Q_DECLARE_TYPEINFO(TextAutoGenerateTextMcpProtocolCore::McpProtocolEmbeddedResource, Q_RELOCATABLE_TYPE);
TEXTAUTOGENERATETEXTMCPPROTOCOLCORE_EXPORT QDebug operator<<(QDebug d, const TextAutoGenerateTextMcpProtocolCore::McpProtocolEmbeddedResource &t);
